%global srcname borgbackup

Name:           %{srcname}
Version:        1.2.7
Release:    1%{?dist}
Summary:        A deduplicating backup program with compression and authenticated encryption
License:        BSD-3-clause AND zlib AND Apache-2.0 AND PSF-2.0

URL:            https://borgbackup.readthedocs.org
Source0:        https://github.com/borgbackup/borg/releases/download/%{version}/borgbackup-%{version}.tar.gz
Source1:        https://github.com/borgbackup/borg/releases/download/%{version}/borgbackup-%{version}.tar.gz.asc
Source2:        gpgkey-6D5B_EF9A_DD20_7580_5747_B70F_9F88_FB52_FAF7_B393.gpg

Patch1:         0002-disable-sphinx-man-page-build.patch

BuildRequires:  gnupg2
BuildRequires:  python3-Cython
BuildRequires:  python3-devel
BuildRequires:  python3-pkgconfig

BuildRequires:  python3dist(python-dateutil)
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(pytest-xdist)

BuildRequires:  python3-sphinx

BuildRequires:  gcc
BuildRequires:  openssl-devel >= 1.0.2
BuildRequires:  fuse-devel
BuildRequires:  make
BuildRequires:  libacl-devel
BuildRequires:  lz4-devel >= 1.7.0
BuildRequires:  libzstd-devel >= 1.3.0
BuildRequires:  xxhash-devel >= 0.7.3

Requires:       python3-llfuse >= 1.3.8
Requires:       fuse

%description
BorgBackup (short: Borg) is a deduplicating backup program. Optionally, it
supports compression and authenticated encryption.

%prep
%{gpgverify} --keyring='%{SOURCE2}' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%autosetup -p1
rm -rf %{srcname}.egg-info

rm -rf src/borg/algorithms/{lz4,xxh64,zstd}
find src/ -name '*.pyx' | sed -e 's/.pyx/.c/g' | xargs rm -f

sed -i 's/msgpack-python/msgpack/' setup.py

%generate_buildrequires
%pyproject_buildrequires -x fuse


%build
%pyproject_wheel

export READTHEDOCS=True

export PYTHONPATH=$(pwd)/build/$(ls build/ | grep 'lib.')

make -C docs SPHINXBUILD=sphinx-build-%python3_version man


%install
find . -name *.so -type f -exec chmod 0755 {} \;

%pyproject_install
install -D -m 0644 docs/_build/man/borg*.1* %{buildroot}%{_mandir}/man1/borg.1

%define bash_compdir %{_prefix}/share/bash-completion/completions
%define zsh_compdir %{_prefix}/share/zsh/site-functions
%define fish_compdir %{_prefix}/share/fish/completions

install -d  %{buildroot}%{bash_compdir}
install -d  %{buildroot}%{zsh_compdir}
install -d  %{buildroot}%{fish_compdir}

install -D -m 0644 scripts/shell_completions/bash/* %{buildroot}%{bash_compdir}
install -D -m 0644 scripts/shell_completions/zsh/* %{buildroot}%{zsh_compdir}
install -D -m 0644 scripts/shell_completions/fish/* %{buildroot}%{fish_compdir}

%check
export PYTHONPATH=%{buildroot}%{python3_sitearch}

cp conftest.py $PYTHONPATH
cd $PYTHONPATH
TEST_SELECTOR="not test_fuse and not test_readonly_mount and not benchmark"
%pytest -n auto -x -vk "$TEST_SELECTOR" borg/testsuite/*.py


%files
%license LICENSE
%doc README.rst AUTHORS
%doc docs/changes.rst
%{_mandir}/man1/*

%{python3_sitearch}/borg
%{python3_sitearch}/borgbackup-%{version}.dist-info
%{_bindir}/borg
%{_bindir}/borgfs
%{_prefix}/share/bash-completion/completions/*
%{_prefix}/share/zsh/site-functions/*
%{_prefix}/share/fish/completions/*
%exclude %{python3_sitearch}/conftest.py
%exclude %{python3_sitearch}/.pytest_cache


%changelog
* Thu Apr 11 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.2.7-1
- initial build
